@@ -16,27 +16,16 @@
 
 import os
 
-from pipeline.backend.config import Backend, WorkMode
 from pipeline.backend.pipeline import PipeLine
 
 # path to data
 # default fate installation path
 DATA_BASE = "/data/projects/fate"
 
-# site-package ver
-# import site
-# DATA_BASE = site.getsitepackages()[0]
-
 
 def main():
     # parties config
     guest = 9999
-    # 0 for eggroll, 1 for spark
-    backend = Backend.EGGROLL
-    # 0 for standalone, 1 for cluster
-    work_mode = WorkMode.STANDALONE
-    # use the work mode below for cluster deployment
-    # work_mode = WorkMode.CLUSTER
 
     # partition for data storage
     partition = 4
@@ -59,7 +48,7 @@ def main():
                                     head=0, partition=partition)
 
     # upload all data
-    pipeline_upload.upload(work_mode=work_mode, backend=backend, drop=1)
+    pipeline_upload.upload(drop=1)
 
 
 if __name__ == "__main__":
