@@ -23,11 +23,11 @@ from pipeline.param.encrypted_mode_calculation_param import EncryptedModeCalcula
 from pipeline.param.cross_validation_param import CrossValidationParam
 from pipeline.param.predict_param import PredictParam
 from pipeline.param import consts
+from pipeline.param.callback_param import CallbackParam
 import copy
 import collections
 
 
-
 class ObjectiveParam(BaseParam):
     """
     Define objective parameters that used in federated ml.
@@ -54,8 +54,6 @@ class ObjectiveParam(BaseParam):
 
         descr = "objective param's"
 
-        LOGGER.debug('check objective {}'.format(self.objective))
-
         if task_type not in [consts.CLASSIFICATION, consts.REGRESSION]:
             self.objective = self.check_and_change_lower(self.objective,
                                                    ["cross_entropy", "lse", "lae", "huber", "fair",
@@ -446,12 +444,10 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
 
         other_rate: float, the retain ratio of small gradient data, used when run_goss is True
 
-        cipher_compress_error： int between [0-15], default is None. The parameter to control pallier cipher compressing.
-                        When cipher compressing is enabled, communication cost will be reduced, algorithms may run f
-                        aster due to lower decrypt cost. However, performance will be influenced by the precision
-                        loss caused by cipher compress.
-                        'None' means disable cipher compress.
-                        A specified integer indicates the rounding decimal precision.
+        cipher_compress_error： This param is now abandoned
+
+        cipher_compress: bool, default is True, use cipher compressing to reduce computation cost and transfer cost
+
         """
 
     def __init__(self, tree_param: DecisionTreeParam = DecisionTreeParam(), task_type=consts.CLASSIFICATION,
@@ -465,7 +461,8 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
                  complete_secure=False, metrics=None, use_first_metric_only=False, random_seed=100,
                  binning_error=consts.DEFAULT_RELATIVE_ERROR,
                  sparse_optimization=False, run_goss=False, top_rate=0.2, other_rate=0.1,
-                 cipher_compress_error=None, new_ver=True):
+                 cipher_compress_error=None, cipher_compress=True, new_ver=True,
+                 callback_param=CallbackParam()):
 
         super(HeteroSecureBoostParam, self).__init__(task_type, objective_param, learning_rate, num_trees,
                                                      subsample_feature_rate, n_iter_no_change, tol, encrypt_param,
@@ -475,7 +472,7 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
                                                      random_seed=random_seed,
                                                      binning_error=binning_error)
 
-        self.tree_param = tree_param
+        self.tree_param = copy.deepcopy(tree_param)
         self.zero_as_missing = zero_as_missing
         self.use_missing = use_missing
         self.complete_secure = complete_secure
@@ -484,7 +481,9 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         self.top_rate = top_rate
         self.other_rate = other_rate
         self.cipher_compress_error = cipher_compress_error
+        self.cipher_compress = cipher_compress
         self.new_ver = new_ver
+        self.callback_param = copy.deepcopy(callback_param)
 
     def check(self):
 
@@ -499,31 +498,16 @@ class HeteroSecureBoostParam(HeteroBoostingParam):
         self.check_boolean(self.run_goss, 'run goss')
         self.check_decimal_float(self.top_rate, 'top rate')
         self.check_decimal_float(self.other_rate, 'other rate')
+        self.check_positive_number(self.other_rate, 'other_rate')
+        self.check_positive_number(self.top_rate, 'top_rate')
         self.check_boolean(self.new_ver, 'code version switcher')
+        self.check_boolean(self.cipher_compress, 'cipher compress')
 
         if self.top_rate + self.other_rate >= 1:
             raise ValueError('sum of top rate and other rate should be smaller than 1')
 
-        if self.cipher_compress_error is not None:
-            self.check_positive_integer(self.cipher_compress_error, 'cipher_compress_error')
-            if self.cipher_compress_error > 15:
-                raise ValueError('cipher compress error exceeds max value 15.')
-
-            # safety check
-            if self.encrypt_param.method != consts.PAILLIER:
-                LOGGER.warning('cipher compressing only supports Paillier, however, encrypt method is {}, '
-                               'this function will be disabled automatically'.
-                               format(self.encrypt_param.method))
-                self.cipher_compress_error = None
-
-            if self.task_type != consts.CLASSIFICATION:
-                LOGGER.warning('cipher compressing only supports classification tasks'
-                               'this function will be disabled automatically')
-                self.cipher_compress_error = None
-
-            if not self.new_ver:
-                LOGGER.warning('old version code does not support cipher compressing')
-                self.cipher_compress_error = None
+        if self.sparse_optimization and self.cipher_compress:
+            raise ValueError('cipher compress is not supported in sparse optimization mode')
 
         return True
 
@@ -540,7 +524,8 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
                  validation_freqs=None, early_stopping_rounds=None, use_missing=False, zero_as_missing=False,
                  complete_secure=False, tree_num_per_party=1, guest_depth=1, host_depth=1, work_mode='mix', metrics=None,
                  sparse_optimization=False, random_seed=100, binning_error=consts.DEFAULT_RELATIVE_ERROR,
-                 cipher_compress_error=None, new_ver=True, run_goss=False, top_rate=0.2, other_rate=0.1):
+                 cipher_compress_error=None, new_ver=True, run_goss=False, top_rate=0.2, other_rate=0.1,
+                 cipher_compress=True, callback_param=CallbackParam()):
 
         """
         work_mode：
@@ -568,12 +553,15 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
                                                          binning_error=binning_error,
                                                          cipher_compress_error=cipher_compress_error,
                                                          new_ver=new_ver,
-                                                         run_goss=run_goss, top_rate=top_rate, other_rate=other_rate)
+                                                         cipher_compress=cipher_compress,
+                                                         run_goss=run_goss, top_rate=top_rate, other_rate=other_rate
+                                                         )
 
         self.tree_num_per_party = tree_num_per_party
         self.guest_depth = guest_depth
         self.host_depth = host_depth
         self.work_mode = work_mode
+        self.callback_param = copy.deepcopy(callback_param)
 
     def check(self):
 
@@ -595,13 +583,18 @@ class HeteroFastSecureBoostParam(HeteroSecureBoostParam):
 
 class HomoSecureBoostParam(BoostingParam):
 
+    """
+    backend: str, defalt is 'distributed', allowed values are: 'distributed', 'memory'
+            decides which backend to use when computing histograms for homo-sbt
+    """
+
     def __init__(self, tree_param: DecisionTreeParam = DecisionTreeParam(), task_type=consts.CLASSIFICATION,
                  objective_param=ObjectiveParam(),
                  learning_rate=0.3, num_trees=5, subsample_feature_rate=1, n_iter_no_change=True,
                  tol=0.0001, bin_num=32, predict_param=PredictParam(), cv_param=CrossValidationParam(),
                  validation_freqs=None, use_missing=False, zero_as_missing=False, random_seed=100,
-                 binning_error=consts.DEFAULT_RELATIVE_ERROR
-                 ):
+                 binning_error=consts.DEFAULT_RELATIVE_ERROR, backend=consts.DISTRIBUTED_BACKEND,
+                 callback_param=CallbackParam()):
         super(HomoSecureBoostParam, self).__init__(task_type=task_type,
                                                    objective_param=objective_param,
                                                    learning_rate=learning_rate,
@@ -618,7 +611,9 @@ class HomoSecureBoostParam(BoostingParam):
                                                    )
         self.use_missing = use_missing
         self.zero_as_missing = zero_as_missing
-        self.tree_param = tree_param
+        self.tree_param = copy.deepcopy(tree_param)
+        self.backend = backend
+        self.callback_param = copy.deepcopy(callback_param)
 
     def check(self):
         super(HomoSecureBoostParam, self).check()
@@ -627,5 +622,6 @@ class HomoSecureBoostParam(BoostingParam):
             raise ValueError('use missing should be bool type')
         if type(self.zero_as_missing) != bool:
             raise ValueError('zero as missing should be bool type')
+        if self.backend not in [consts.MEMORY_BACKEND, consts.DISTRIBUTED_BACKEND]:
+            raise ValueError('unsupported backend')
         return True
-
